@@ -24,7 +24,7 @@ gbifissues <- structure(list(
            "txmatfuz", "txmathi", "txmatnon", "typstativ", "zerocd",
            "cdpi", "cdumi", "indci", "interr", "iccos", "osiic", "osu",
            "geodi","geodu", "ambcol", "ambinst", "colmafu", "colmano",
-           "incomis", "inmafu", "inmano", "osifbor", "ploan",
+           "incomis", "inmafu", "inmano", "osifbor", "diffown",
            "anm", "annu", "anuidi", "aitidinv", "bbmn", "basauthm",
            "bibrinv", "chsun", "clasna", "clasroi", "conbascomb", "desinv",
            "disinv", "hom", "minv", "npm", "ns","nsinv", "onder", "onnu",
@@ -53,7 +53,7 @@ gbifissues <- structure(list(
             "AMBIGUOUS_INSTITUTION", "COLLECTION_MATCH_FUZZY", "COLLECTION_MATCH_NONE",
             "INSTITUTION_COLLECTION_MISMATCH", "INSTITUTION_MATCH_FUZZY",
             "INSTITUTION_MATCH_NONE", "OCCURRENCE_STATUS_INFERRED_FROM_BASIS_OF_RECORD",
-            "POSSIBLY_ON_LOAN",
+            "DIFFERENT_OWNER_INSTITUTION",
             "ACCEPTED_NAME_MISSING", "ACCEPTED_NAME_NOT_UNIQUE", "ACCEPTED_NAME_USAGE_ID_INVALID",
             "ALT_IDENTIFIER_INVALID", "BACKBONE_MATCH_NONE",
             "BASIONYM_AUTHOR_MISMATCH", "BIB_REFERENCE_INVALID", "CHAINED_SYNOYM",
@@ -117,7 +117,7 @@ gbifissues <- structure(list(
                   "The given institution was fuzzily matched to a GrSciColl institution.",
                   "The given institution couldn't be matched with any GrSciColl institution.",
                   "Occurrence status was inferred from basis of records",
-                  "The given owner institution is different than the given institution.",
+                  "The given owner institution is different than the given institution. Therefore we assume it doesn't belong to the institution and we don't link it to the occurrence.",
                   "Synonym lacking an accepted name.",
                   "Synonym has a verbatim accepted name which is not unique and refers to several records.",
                   "The value for dwc:acceptedNameUsageID could not be resolved.",
